<?php
/**
 * The Ulaform script to delete a form.
 *
 * $Horde: ulaform/delete.php,v 1.32 2007/01/02 12:49:11 jan Exp $
 *
 * Copyright 2003-2007 The Horde Project (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * @author Marko Djukic <marko@oblo.com>
 */

@define('ULAFORM_BASE', dirname(__FILE__));
require_once ULAFORM_BASE . '/lib/base.php';
require_once 'Horde/Variables.php';

/* Only admin should be using this. */
if (!Auth::isAdmin()) {
    Horde::authenticationFailureRedirect();
}

$delvars = Variables::getDefaultVariables();
$form_id = $delvars->get('form_id');
$form_submit = $delvars->get('submitbutton');

/* Set up the forms. */
$viewvars = new Variables($ulaform->getForm($form_id));
$viewform = new Horde_Form($viewvars, _("Form Details"));
$delform = new Horde_Form($delvars, _("Delete this form?"));
$viewform->addVariable(_("Name"), 'form_name', 'text', false);
$viewform->addVariable(_("Action"), 'form_action', 'email', false);
$delform->setButtons(array(_("Delete"), _("Do not delete")));
$delform->addHidden('', 'form_id', 'int', true);

if ($form_submit == _("Delete")) {
    $delform->validate($delvars);

    if ($delform->isValid()) {
        $delform->getInfo($delvars, $info);
        $deleteform = $ulaform->deleteForm($info['form_id']);
        if (is_a($deleteform, 'PEAR_Error')) {
            Horde::logMessage($deleteform, __FILE__, __LINE__, PEAR_LOG_ERR);
            $notification->push(sprintf(_("Error deleting form. %s."), $deleteform->getMessage()), 'horde.error');
        } else {
            $notification->push(_("Form deleted."), 'horde.success');
            $url = Horde::applicationUrl('forms.php', true);
            header('Location: ' . $url);
            exit;
        }
    }
} elseif (!empty($form_submit)) {
    $notification->push(_("Form has not been deleted."), 'horde.message');
    $url = Horde::applicationUrl('forms.php', true);
    header('Location: ' . $url);
    exit;
}

/* Render the form. */
$renderer = new Horde_Form_Renderer();
$main = Util::bufferOutput(array($delform, 'renderActive'), $renderer, $delvars, 'delete.php', 'post') .
        Util::bufferOutput(array($viewform, 'renderInactive'), $renderer, $viewvars);

$template->set('main', $main);
$template->set('menu', Ulaform::getMenu('string'));
$template->set('notify', Util::bufferOutput(array($notification, 'notify'), array('listeners' => 'status')));

require ULAFORM_TEMPLATES . '/common-header.inc';
echo $template->fetch(ULAFORM_TEMPLATES . '/main/main.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
